#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Copyright 2022 Stéphane Caron
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Load a robot description in `RoboMeshCat
<https://github.com/petrikvladimir/RoboMeshCat>`_.
"""

from importlib import import_module  # type: ignore

import robomeshcat

from .pinocchio import get_package_dirs


def load_robot_description(description_name: str) -> robomeshcat.Robot:
    """
    Load a robot description in RoboMeshCat.

    Args:
        description_name: Name of the robot description.

    Returns:
        Robot model for RoboMeshCat.
    """
    module = import_module(f"robot_descriptions.{description_name}")
    robot = robomeshcat.Robot(
        urdf_path=module.URDF_PATH,
        mesh_folder_path=get_package_dirs(module),
    )
    return robot
